@@ -1,7 +1,7 @@
 package Complete::Util;
 
 our $DATE = '2015-04-25'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -520,6 +520,17 @@ sub combine_answers {
             }
         }
     }
+
+    # re-sort final words
+    if ($final->{words}) {
+        $final->{words} = [
+            sort {
+                (ref($a) ? $a->{word} : $a) cmp
+                    (ref($b) ? $b->{word} : $b);
+            }
+                @{ $final->{words} }];
+    }
+
     $encounter_hash ? $final : $final->{words};
 }
 
@@ -542,7 +553,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.28 of Complete::Util (from Perl distribution Complete-Util), released on 2015-04-25.
+This document describes version 0.29 of Complete::Util (from Perl distribution Complete-Util), released on 2015-04-25.
 
 =head1 DESCRIPTION
 
